@@ -21,6 +21,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__LIBWNCK_H_INSIDE__) && !defined (WNCK_COMPILATION)
+#error "Only <libwnck/libwnck.h> can be included directly."
+#endif
+
 #ifndef WNCK_WINDOW_H
 #define WNCK_WINDOW_H
 
@@ -295,7 +299,10 @@ WnckWindow*      wnck_window_get_transient    (WnckWindow *window);
 gulong           wnck_window_get_group_leader (WnckWindow *window);
 gulong           wnck_window_get_xid          (WnckWindow *window);
 
-WnckClassGroup *wnck_window_get_class_group (WnckWindow *window);
+WnckClassGroup *wnck_window_get_class_group   (WnckWindow *window);
+
+const char* wnck_window_get_class_group_name    (WnckWindow *window);
+const char* wnck_window_get_class_instance_name (WnckWindow *window);
 
 const char* wnck_window_get_session_id        (WnckWindow *window);
 const char* wnck_window_get_session_id_utf8   (WnckWindow *window);
